@@ -103,15 +103,40 @@ thermo.axis <- function(lab='x-axis',side=1,line=1.5,cex=par('cex'),lwd=par('lwd
   if(!is.null(T)) par(opar)
 }
 
-label.plot <- function(x,xfrac=0.95,yfrac=0.9,cex=1,paren=TRUE,adj=1) {
+label.plot <- function(x, xfrac=0.05, yfrac=0.95, paren=FALSE, italic=FALSE, ...) {
   # make a text label e.g., "(a)" in the corner of a plot
   # xfrac, yfrac: fraction of axis where to put label (default top right)
   # paren: put a parenthesis around the text, and italicize it?
-  if(paren) x <- as.expression(substitute(group('(',italic(a),')'),list(a=x)))
+  if(italic) x <- substitute(italic(a), list(a=x))
+  if(paren) x <- substitute(group('(',a,')'), list(a=x))
+  if(italic | paren) x <- as.expression(x)
   pu <- par('usr')
-  text( pu[1]+xfrac*(pu[2]-pu[1]), pu[3]+yfrac*(pu[4]-pu[3]), labels=x, cex=cex , adj=adj)
+  text(pu[1]+xfrac*(pu[2]-pu[1]), pu[3]+yfrac*(pu[4]-pu[3]), labels=x, ...)
 }
 
+usrfig <- function() {
+  # function to get the figure limits in user coordinates
+  # get plot limits in user coordinates (usr) and as fraction [0,1] of figure region (plt)
+  xusr <- par('usr')[1:2]; yusr <- par('usr')[3:4]
+  xplt <- par('plt')[1:2]; yplt <- par('plt')[3:4]
+  # linear model to calculate figure limits in user coordinates
+  xlm <- lm(xusr ~ xplt); ylm <- lm(yusr ~ yplt)
+  xfig <- predict.lm(xlm, data.frame(xplt=c(0, 1)))
+  yfig <- predict.lm(ylm, data.frame(yplt=c(0, 1)))
+  return(list(x=xfig, y=yfig))
+}
+
+label.figure <- function(x, xfrac=0.05, yfrac=0.95, paren=FALSE, italic=FALSE, ...) {
+  # function to add labels outside of the plot region  20151020
+  f <- usrfig()
+  # similar to label.plot(), except we have to set xpd=TRUE here
+  opar <- par(xpd=NA)
+  if(italic) x <- substitute(italic(a), list(a=x))
+  if(paren) x <- substitute(group('(',a,')'), list(a=x))
+  if(italic | paren) x <- as.expression(x)
+  text(f$x[1]+xfrac*(f$x[2]-f$x[1]), f$y[1]+yfrac*(f$y[2]-f$y[1]), labels=x, ...)
+  par(opar)
+}
 
 water.lines <- function(xaxis='pH', yaxis='Eh', T=298.15, P='Psat', which=c('oxidation','reduction'),
   logaH2O=0, lty=2, lwd=1, col=par('fg'), xpoints=NULL, O2state="gas") {
@@ -127,13 +152,14 @@ water.lines <- function(xaxis='pH', yaxis='Eh', T=298.15, P='Psat', which=c('oxi
   ylim <- pu[3:4]
   # exact lines
   # warning: Eh calculations are reliable only at a single T
-  if(xaxis=='pH' & (yaxis=='Eh' | yaxis=='O2' | yaxis=="pe")) {
+  if(xaxis=="O2" | (xaxis=='pH' & (yaxis=='Eh' | yaxis=='O2' | yaxis=="pe"))) {
     if('reduction' %in% which) {
       logfH2 <- 0
       logK <- subcrt(c("H2O", "O2", "H2"), c(-1, 0.5, 1), c("liq", O2state, "gas"), T=T, P=P, convert=FALSE)$out$logK 
       # this is logfO2 if O2state=="gas", or logaO2 if O2state=="aq"
       logfO2 <- 2 * logK - logfH2 + 2 * logaH2O
-      if(yaxis=='O2') abline(h=logfO2,lty=lty,lwd=lwd,col=col) 
+      if(xaxis=='O2') abline(v=logfO2,lty=lty,lwd=lwd,col=col) 
+      else if(yaxis=='O2') abline(h=logfO2,lty=lty,lwd=lwd,col=col) 
       else if(yaxis=="Eh") lines(xlim,convert(logfO2,'E0',T=T,P=P,pH=xlim),lty=lty,lwd=lwd,col=col)
       else if(yaxis=="pe") lines(xlim,convert(convert(logfO2,'E0',T=T,P=P,pH=xlim),"pe",T=T),lty=lty,lwd=lwd,col=col)
     }
@@ -142,6 +168,7 @@ water.lines <- function(xaxis='pH', yaxis='Eh', T=298.15, P='Psat', which=c('oxi
       logK <- subcrt(c("O2", "O2"), c(-1, 1), c("gas", O2state), T=T, P=P, convert=FALSE)$out$logK 
       # this is logfO2 if O2state=="gas", or logaO2 if O2state=="aq"
       logfO2 <- logfO2 + logK
+      if(xaxis=='O2') abline(v=logfO2,lty=lty,lwd=lwd,col=col) 
       if(yaxis=='O2') abline(h=logfO2,lty=lty,lwd=lwd,col=col) 
       else if(yaxis=="Eh") lines(xlim,convert(logfO2,'E0',T=T,P=P,pH=xlim),lty=lty,lwd=lwd,col=col)
       else if(yaxis=="pe") lines(xlim,convert(convert(logfO2,'E0',T=T,P=P,pH=xlim),"pe",T=T),lty=lty,lwd=lwd,col=col)
@@ -175,11 +202,12 @@ water.lines <- function(xaxis='pH', yaxis='Eh', T=298.15, P='Psat', which=c('oxi
   }
 }
 
-mtitle <- function(main,...) {
+mtitle <- function(main, line=0, ...) {
   # make a possibly multi-line plot title 
   # useful for including expressions on multiple lines 
+  # 'line' is the margin line of the last (bottom) line of the title
   l <- length(main)
-  for(i in 1:l) mtext(main[i],line=l-i,...)
+  for(i in 1:l) mtext(main[i], line=line+l-i, ...)
 }
 
 
